==> react-native-hotqa-sdk-0.0.22.tgz: package/src/components/tag/Tag.js <==
// @flow

import React, {PureComponent} from 'react';
import {Text, TouchableOpacity, View} from 'react-native';
import Icon from 'react-native-vector-icons/Ionicons';
import type {NativeMethodsMixinType} from 'react-native/Libraries/Renderer/shims/ReactNativeTypes';
import type {TagObject} from './types';

type Props = {
  tag: TagObject,
  // Called when user taps on a tag
  onPress: (tag: TagObject) => void,
  // Called after a tag is rendered
  onRender: (
    tag: TagObject,
    screenX: number,
    screenY: number,
    width: number,
    height: number,
  ) => void,
};

export default class Tag extends PureComponent {
  props: Props;

  container: ?NativeMethodsMixinType;

  // Append styles.tagBeingDragged style if tag is being dragged
  getTagStyle = (): {} => ({
    ...styles.tag,
    ...(this.props.tag.isBeingDragged ? styles.tagBeingDragged : {}),
  });

  // Call view container's measure function to measure tag position on the screen
  onLayout = (): void => {
    this.container && this.container.measure(this.onMeasure);
  };

  // Pass tag coordinates up to the parent component
  onMeasure = (
    x: number,
    y: number,
    width: number,
    height: number,
    screenX: number,
    screenY: number,
  ): void => {
    this.props.onRender(this.props.tag, screenX, screenY, width, height);
  };

  // Handle tag taps
  onPress = (): void => {
    this.props.onPress(this.props.tag);
  };

  render() {
    const {
      tag: {title},
    } = this.props;
    return (
      <View
        ref={(el) => (this.container = el)}
        style={styles.container}
        onLayout={this.onLayout}>
        {title.length > 0 ? (
          <TouchableOpacity
            style={this.getTagStyle()}
            onPress={() => this.onPress()}>
            <Text style={styles.title}>{title}</Text>
          </TouchableOpacity>
        ) : (
          <Text style={styles.title}>_____</Text>
        )}
      </View>
    );
  }
}

const styles = {
  container: {
    marginBottom: 10,
    marginRight: 6,
    minWidth: 50,
  },
  tag: {
    flexDirection: 'row',
    alignItems: 'center',
    backgroundColor: 'rgba(255, 255, 255, .33)',
    borderColor: '#FDA429',
    borderRadius: 20,
    borderWidth: 1,
    paddingHorizontal: 10,
    paddingVertical: 5,
    justifyContent: 'center',
  },
  tagBeingDragged: {
    backgroundColor: '#eee',
    borderStyle: 'dashed',
  },
  title: {
    color: 'black',
    fontSize: 15,
    textAlign: 'center',
  },
};

==> react-native-hotqa-sdk-0.1.1.tgz: package/src/components/tag/Tag.js <==
// @flow

import React, {PureComponent} from 'react';
import {Text, TouchableOpacity, View} from 'react-native';
import Icon from 'react-native-vector-icons/Ionicons';
import type {NativeMethodsMixinType} from 'react-native/Libraries/Renderer/shims/ReactNativeTypes';
import SharePreference from '../../common/SharePreference';
import type {TagObject} from './types';
import * as colors from '../../assets/colors';

type Props = {
  tag: TagObject,
  // Called when user taps on a tag
  onPress: (tag: TagObject) => void,
  // Called after a tag is rendered
  onRender: (
    tag: TagObject,
    screenX: number,
    screenY: number,
    width: number,
    height: number,
  ) => void,
};

export default class Tag extends PureComponent {
  props: Props;

  container: ?NativeMethodsMixinType;

  // Append styles.tagBeingDragged style if tag is being dragged
  getTagStyle = (): {} => ({
    ...styles.tag,
    ...(this.props.tag.isBeingDragged ? styles.tagBeingDragged : {}),
    ...(this.props.tagSelected && {backgroundColor: colors.color_blue}),
  });

  // Call view container's measure function to measure tag position on the screen
  onLayout = (): void => {
    this.container && this.container.measure(this.onMeasure);
  };

  // Pass tag coordinates up to the parent component
  onMeasure = (
    x: number,
    y: number,
    width: number,
    height: number,
    screenX: number,
    screenY: number,
  ): void => {
    this.props.onRender(this.props.tag, screenX, screenY, width, height);
  };

  // Handle tag taps
  onPress = (): void => {
    this.props.onPress(this.props.tag);
  };

  render() {
    const {
      tag: {title},
      tagSelected,
    } = this.props;
    return (
      <View
        ref={(el) => (this.container = el)}
        style={styles.container}
        onLayout={this.onLayout}>
        {title.length > 0 ? (
          <TouchableOpacity
            activeOpacity={0.5}
            disabled={SharePreference.isFinish}
            style={this.getTagStyle()}
            onPress={() => this.onPress()}>
            <Text style={[styles.title, tagSelected && {color: '#FFF'}]}>
              {title}
            </Text>
          </TouchableOpacity>
        ) : (
          <Text style={styles.title}>_____</Text>
        )}
      </View>
    );
  }
}

const styles = {
  container: {
    marginBottom: 10,
    marginRight: 6,
    minWidth: 50,
  },
  tag: {
    flexDirection: 'row',
    alignItems: 'center',
    backgroundColor: colors.color_orange,
    // borderColor: '#FDA429',
    borderRadius: 12,
    // borderWidth: 1,
    paddingHorizontal: 12,
    paddingVertical: 8,
    justifyContent: 'center',
  },
  tagBeingDragged: {
    backgroundColor: '#eee',
    borderStyle: 'dashed',
  },
  title: {
    color: colors.color_blue,
    fontSize: 18,
    textAlign: 'center',
  },
};
